Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(172)

Unified Diff: content/public/common/platform_notification_data.h

Issue 1855443002: Implement receiving side of web notification inline replies (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/platform_notification_data.h
diff --git a/content/public/common/platform_notification_data.h b/content/public/common/platform_notification_data.h
index b96cd802f8576639c0262e91d1bb540da7466602..39ec2b657b798ed3ea031ac473b1769297cf76ac 100644
--- a/content/public/common/platform_notification_data.h
+++ b/content/public/common/platform_notification_data.h
@@ -17,11 +17,24 @@
namespace content {
-// A notification action (button); corresponds to Blink WebNotificationAction.
+enum CONTENT_EXPORT PlatformNotificationActionType {
+ PLATFORM_NOTIFICATION_ACTION_TYPE_BUTTON = 0,
+ PLATFORM_NOTIFICATION_ACTION_TYPE_TEXT,
+};
+
+// A notification action (button or text input); corresponds to Blink
+// WebNotificationAction.
struct CONTENT_EXPORT PlatformNotificationAction {
PlatformNotificationAction();
~PlatformNotificationAction();
+ // Type of the action (button or text input).
+ PlatformNotificationActionType type;
+
+ // Optional text to use as placeholder for text inputs. May be empty if it was
+ // not specified.
+ base::string16 placeholder;
+
// Action name that the author can use to distinguish them.
std::string action;

Powered by Google App Engine
This is Rietveld 408576698